@@ -3,7 +3,7 @@
 // RcppCommon.h: Rcpp R/C++ interface class library -- common include and defines statements
 //
 // Copyright (C) 2008 - 2009  Dirk Eddelbuettel
-// Copyright (C) 2009 - 2015  Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2009 - 2017  Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -98,7 +98,7 @@ namespace Rcpp {
         if (Rf_isNull(x)) {
             Rcpp_PreserveObject(y);
         } else if (Rf_isNull(y)) {
-            Rcpp_ReleaseObject(x);
+            Rcpp_ReleaseObject(x); 	// #nocov
         } else {
             // if we are setting to the same SEXP as we already have, do nothing
             if (x != y) {
@@ -126,7 +126,7 @@ namespace Rcpp {
 #include <Rcpp/complex.h>
 #include <Rcpp/barrier.h>
 
-#define RcppExport extern "C"
+#define RcppExport extern "C" attribute_visible
 
 #include <Rcpp/exceptions.h>
 
@@ -135,9 +135,9 @@ namespace Rcpp {
 namespace Rcpp {
     template <typename T> class object;
     class String;
-        namespace internal {
-            template <typename Class> SEXP make_new_object(Class* ptr);
-        }
+    namespace internal {
+        template <typename Class> SEXP make_new_object(Class* ptr);
+    }
 }
 
 #include <Rcpp/longlong.h>
